"""Product blocks for Layer 3 Core Service products."""

from orchestrator.domain.base import ProductBlockModel
from orchestrator.types import SubscriptionLifecycle
from pydantic import Field

from gso.products.product_blocks.service_binding_port import (
    ServiceBindingPort,
    ServiceBindingPortInactive,
    ServiceBindingPortProvisioning,
)
from gso.utils.shared_enums import APType


class AccessPortInactive(ProductBlockModel, lifecycle=[SubscriptionLifecycle.INITIAL], product_block_name="AccessPort"):
    """An access port for an R&E service that is inactive."""

    ap_type: APType | None = None
    sbp: ServiceBindingPortInactive


class AccessPortProvisioning(AccessPortInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """An access port for an R&E service that is being provisioned."""

    ap_type: APType
    sbp: ServiceBindingPortProvisioning


class AccessPort(AccessPortProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An access port for an R&E service."""

    #: The type of Access Port
    ap_type: APType
    #: The corresponding SBP of this Access Port.
    sbp: ServiceBindingPort


class L3CoreServiceBlockInactive(
    ProductBlockModel, lifecycle=[SubscriptionLifecycle.INITIAL], product_block_name="L3CoreServiceBlock"
):
    """An inactive L3 Core service subscription. See ``L3CoreServiceBlock``."""

    ap_list: list[AccessPortInactive] = Field(default_factory=list)


class L3CoreServiceBlockProvisioning(L3CoreServiceBlockInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """A provisioning L3 Core Service subscription. See ``L3CoreServiceBlock``."""

    ap_list: list[AccessPortProvisioning]  # type: ignore[assignment]


class L3CoreServiceBlock(L3CoreServiceBlockProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An active L3 Core Service subscription block."""

    #: The list of Access Points where this service is present.
    ap_list: list[AccessPort]  # type: ignore[assignment]
