"""Import an existing LAN Switch Interconnect into the service database."""

from orchestrator import step, workflow
from orchestrator.targets import Target
from orchestrator.types import State, UUIDstr
from orchestrator.workflow import StepList, begin, done
from orchestrator.workflows.steps import resync, store_process_subscription, unsync
from orchestrator.workflows.utils import wrap_modify_initial_input_form

from gso.products import ProductName
from gso.products.product_types.lan_switch_interconnect import ImportedLanSwitchInterconnect, LanSwitchInterconnect
from gso.services.subscriptions import get_product_id_by_name


@step("Create new switch subscription")
def import_lan_switch_interconnect_subscription(subscription_id: UUIDstr) -> State:
    """Take an imported subscription, and turn it into a full subscription."""
    old_subscription = ImportedLanSwitchInterconnect.from_subscription(subscription_id)
    new_subscription_id = get_product_id_by_name(ProductName.LAN_SWITCH_INTERCONNECT)
    new_subscription = LanSwitchInterconnect.from_other_product(old_subscription, new_subscription_id)  # type: ignore[arg-type]

    return {"subscription": new_subscription}


@workflow(
    "Import LAN Switch Interconnect", target=Target.MODIFY, initial_input_form=wrap_modify_initial_input_form(None)
)
def import_lan_switch_interconnect() -> StepList:
    """Modify an ImportedLanSwitchInterconnect subscription into subscription to complete the import."""
    return (
        begin
        >> store_process_subscription(Target.MODIFY)
        >> unsync
        >> import_lan_switch_interconnect_subscription
        >> resync
        >> done
    )
