"""A task that checks for all products in the database to be well-kept."""

# .. vale off
# Copyright 2019-2020 SURF.
# Copyright 2024 GÉANT Vereniging.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# .. vale on

from orchestrator.targets import Target
from orchestrator.workflow import StepList, done, init, workflow
from orchestrator.workflows.tasks.validate_products import (
    check_all_workflows_are_in_db,
    check_db_fixed_input_config,
    check_subscription_models,
    check_that_products_have_create_modify_and_terminate_workflows,
    check_workflows_for_matching_targets_and_descriptions,
)


@workflow("Validate GEANT products", target=Target.SYSTEM)
def task_validate_geant_products() -> StepList:
    """Validate products in the database.

    This task is based on the ``task_validate_products`` present in ``orchestrator-core`` but it does not check for the
    existence of the ``modify_note`` workflow on all products, since this workflow is currently not used in GEANT.
    """
    return (
        init
        >> check_all_workflows_are_in_db
        >> check_workflows_for_matching_targets_and_descriptions
        # >> check_that_products_have_at_least_one_workflow  FIXME: Uncomment as soon as this would pass again
        >> check_db_fixed_input_config
        >> check_that_products_have_create_modify_and_terminate_workflows
        >> check_subscription_models
        >> done
    )
